@@ -17,8 +17,8 @@
 
 InitErgmProposal.discordTNT <- function(arguments, nw, ...) {
   discordance_fraction <- NVL(arguments$discordance_fraction, 1/2)
-  if(!is.numeric(discordance_fraction) || length(discordance_fraction) != 1 || discordance_fraction <= 0 || discordance_fraction >= 1) {
-    ergm_Init_abort("Argument ", sQuote("discordance_fraction"), " to ", sQuote("discordTNT"), " must be a number strictly between 0 and 1.")
+  if(!is.numeric(discordance_fraction) || length(discordance_fraction) != 1 || discordance_fraction < 0 || discordance_fraction >= 1) {
+    ergm_Init_abort("Argument ", sQuote("discordance_fraction"), " to ", sQuote("discordTNT"), " must be a number in [0,1).")
   }
   
   proposal <- list(name = "discordTNT", inputs=NULL, auxiliaries = ~.lasttoggle, discordance_fraction = discordance_fraction)
@@ -31,5 +31,12 @@ InitErgmProposal.discordBDStratTNT <- function(arguments, nw, ...) {
   proposal <- InitErgmProposal.BDStratTNT(arguments, nw, ...)
   proposal$name <- "discordBDStratTNT"
   proposal$auxiliaries <- ~.lasttoggle
+
+  discordance_fraction <- NVL(arguments$discordance_fraction, 1/2)
+  if(!is.numeric(discordance_fraction) || length(discordance_fraction) != 1 || discordance_fraction < 0 || discordance_fraction >= 1) {
+    ergm_Init_abort("Argument ", sQuote("discordance_fraction"), " to ", sQuote("discordBDStratTNT"), " must be a number in [0,1).")
+  }
+  proposal$discordance_fraction <- as.numeric(discordance_fraction)
+  
   proposal
 }
