@@ -240,17 +240,23 @@ edgelist_with_lasttoggle <- function(nw) {
   
   rv <- cbind(rv, as.integer(-.Machine$integer.max/2)) # default time
   
-  lt <- if(is(nw, "ergm_state")) nw$nw0 %n% "lasttoggle" else nw %n% "lasttoggle"
+  if(is(nw, "ergm_state")) {
+    lt <- nw$nw0 %n% "lasttoggle"
+  } else {
+    lt <- nw %n% "lasttoggle"
+  }
+  if(NROW(lt) == 0) return(rv)
+  
+  lt <- lt[order(lt[,1], lt[,2]),,drop=FALSE]
   
   # if a non-default time exists, use it instead
-  # TODO: it would probably be faster to sort the lasttoggle and do
-  #       sorted lookups of the edges, rather than this linear search
+  j <- 1
   for(i in seq_len(NROW(rv))) {
-    for(j in seq_len(NROW(lt))) {
-      if(rv[i,1] == lt[j,1] && rv[i,2] == lt[j,2]) {
-        rv[i,3] <- lt[j,3]
-        break
-      }
+    while(j < NROW(lt) && (lt[j,1] < rv[i,1] || (lt[j,1] == rv[i,1] && lt[j,2] < rv[i,2]))) {
+      j <- j + 1
+    }
+    if(rv[i,1] == lt[j,1] && rv[i,2] == lt[j,2]) {
+      rv[i,3] <- lt[j,3]
     }
   }
   
